#
# All possible declarations set
#
rule      ALLUSED
describe  All possible declarations used
score     42
wordlim   yes
caseless  yes
meta      AU
tflags    noautolearn,multiple

scan body

alt1
alt2
alt3

scan header From

alt1
alt2
alt3


